@@ -83,7 +83,8 @@ class erstruct:
         print("K_hat is ", K_hat)
         return K_hat
 
-    def gene500(self):
+class Gene500:
+    def download(self):
         data1 = pkg_resources.resource_string(__name__, 'data/char21.npy')
         data2 = pkg_resources.resource_string(__name__, 'data/char22.npy')
         np.save('sample_data/char21.npy', data1)
